@@ -1,12 +1,15 @@
 from sila2.client.client_feature import ClientFeature
 from sila2.client.client_metadata import ClientMetadata, ClientMetadataInstance
 from sila2.client.client_observable_command import ClientObservableCommand
-from sila2.client.client_observable_command_instance import ClientObservableCommandInstance
+from sila2.client.client_observable_command_instance import (
+    ClientObservableCommandInstance,
+    ClientObservableCommandInstanceWithIntermediateResponses,
+)
 from sila2.client.client_observable_property import ClientObservableProperty
 from sila2.client.client_unobservable_command import ClientUnobservableCommand
 from sila2.client.client_unobservable_property import ClientUnobservableProperty
-from sila2.client.no_intermediate_responses import NoIntermediateResponses
 from sila2.client.sila_client import SilaClient
+from sila2.client.subscription import Subscription
 
 __all__ = [
     "ClientFeature",
@@ -14,9 +17,10 @@ __all__ = [
     "ClientMetadataInstance",
     "ClientObservableCommand",
     "ClientObservableCommandInstance",
+    "ClientObservableCommandInstanceWithIntermediateResponses",
     "ClientObservableProperty",
     "ClientUnobservableCommand",
     "ClientUnobservableProperty",
-    "NoIntermediateResponses",
     "SilaClient",
+    "Subscription",
 ]
