@@ -1,6 +1,5 @@
-from typing import TYPE_CHECKING
-
 from .lockcontroller_base import LockControllerBase
+from .lockcontroller_client import LockControllerClient
 from .lockcontroller_errors import InvalidLockIdentifier, ServerAlreadyLocked, ServerNotLocked
 from .lockcontroller_feature import LockControllerFeature
 from .lockcontroller_types import LockServer_Responses, UnlockServer_Responses
@@ -8,14 +7,10 @@ from .lockcontroller_types import LockServer_Responses, UnlockServer_Responses
 __all__ = [
     "LockControllerBase",
     "LockControllerFeature",
+    "LockControllerClient",
     "LockServer_Responses",
     "UnlockServer_Responses",
     "InvalidLockIdentifier",
     "ServerAlreadyLocked",
     "ServerNotLocked",
 ]
-
-if TYPE_CHECKING:
-    from .lockcontroller_client import LockControllerClient  # noqa: F401
-
-    __all__.append("LockControllerClient")
