@@ -15,7 +15,7 @@ if TYPE_CHECKING:
 
 
 class BinaryTransferError(Exception):
-    pb2_module: SiLABinaryTransfer_pb2 = binary_transfer_pb2_module
+    _pb2_module: SiLABinaryTransfer_pb2 = binary_transfer_pb2_module
     error_type: BinaryTransferErrorType
     message: str
 
@@ -25,8 +25,8 @@ class BinaryTransferError(Exception):
         super().__init__(message)
 
     def to_message(self) -> SilaBinaryTransferError:
-        error_type = getattr(self.pb2_module.BinaryTransferError, self.error_type.name)
-        return self.pb2_module.BinaryTransferError(errorType=error_type, message=self.message)
+        error_type = getattr(self._pb2_module.BinaryTransferError, self.error_type.name)
+        return self._pb2_module.BinaryTransferError(errorType=error_type, message=self.message)
 
     @staticmethod
     def is_binary_transfer_error(exception: Exception) -> bool:
@@ -35,7 +35,7 @@ class BinaryTransferError(Exception):
         if not exception.code() == grpc.StatusCode.ABORTED:
             return False
         try:
-            BinaryTransferError.pb2_module.BinaryTransferError.FromString(standard_b64decode(exception.details()))
+            BinaryTransferError._pb2_module.BinaryTransferError.FromString(standard_b64decode(exception.details()))
         except:  # noqa: E722
             return False
         return True
@@ -45,7 +45,7 @@ class BinaryTransferError(Exception):
         if not cls.is_binary_transfer_error(rpc_error):
             raise ValueError("Error is no BinaryTransferError")
 
-        bin_err = cls.pb2_module.BinaryTransferError.FromString(standard_b64decode(rpc_error.details()))
+        bin_err = cls._pb2_module.BinaryTransferError.FromString(standard_b64decode(rpc_error.details()))
         if bin_err.errorType == bin_err.BINARY_DOWNLOAD_FAILED:
             from sila2.framework.binary_transfer.binary_download_failed import BinaryDownloadFailed
 
