@@ -10,7 +10,10 @@ if TYPE_CHECKING:
 
 
 class IntermediateResponse(NamedDataNode):
+    """Represents a command intermediate response"""
+
     fully_qualified_identifier: FullyQualifiedIdentifier
+    """Fully qualified intermediate response identifier"""
     parent_command: Command
 
     def __init__(self, fdl_node, parent_command: Command):
