@@ -12,6 +12,16 @@ if TYPE_CHECKING:
 
 
 class FrameworkError(SilaError):
+    """
+    Base class for all SiLA Framework Errors. Don't use this class directly. Instead, use one of its subclasses:
+
+    - :py:class:`sila2.framework.InvalidCommandExecutionUUID`
+    - :py:class:`sila2.framework.CommandExecutionNotFinished`
+    - :py:class:`sila2.framework.InvalidMetadata`
+    - :py:class:`sila2.framework.NoMetadataAllowed`
+    - :py:class:`sila2.framework.CommandExecutionNotAccepted`
+    """
+
     error_type: FrameworkErrorType
     message: str
 
@@ -20,9 +30,9 @@ class FrameworkError(SilaError):
         self.message = message
 
     def to_message(self) -> SiLAError:
-        return self.pb2_module.SiLAError(
-            frameworkError=self.pb2_module.FrameworkError(
-                errorType=getattr(self.pb2_module.FrameworkError, self.error_type.name),
+        return self._pb2_module.SiLAError(
+            frameworkError=self._pb2_module.FrameworkError(
+                errorType=getattr(self._pb2_module.FrameworkError, self.error_type.name),
                 message=self.message,
             )
         )
