@@ -31,7 +31,6 @@ if TYPE_CHECKING:
     from sila2.framework.feature import Feature
     from sila2.framework.metadata import Metadata
     from sila2.framework.property.property import Property
-    from sila2.server.feature_implementation_servicer import FeatureImplementationServicer
 
     HasFullyQualifiedIdentifier = Union[
         Feature,
@@ -43,7 +42,6 @@ if TYPE_CHECKING:
         DefinedExecutionErrorNode,
         DataTypeDefinition,
         Metadata,
-        FeatureImplementationServicer,
     ]
 
 
